@@ -12,7 +12,7 @@ from rex.utilities.utilities import safe_json_load
 
 from reVX.offshore.dist_to_ports_converter import DistToPortsConverter
 from reVX.utilities.exclusions_converter import ExclusionsConverter
-from reVX.utilities.forecasts import Forecasts
+from reVX.utilities.forecasts import FcstUtils
 from reVX.utilities.output_extractor import output_extractor
 from reVX.utilities.region_classifier import RegionClassifier
 from reVX.wind_setbacks.setbacks_converter import SetbacksConverter
@@ -113,7 +113,7 @@ def correct_forecast(fcst_h5, fcst_dset, out_h5, actuals_h5, actuals_dset,
     - Blend fcst_perc of forecast generation with (1 - fcst_perc) of
     actuals generation
     """
-    Forecasts.correct(fcst_h5, fcst_dset, out_h5, actuals_h5=actuals_h5,
+    FcstUtils.correct(fcst_h5, fcst_dset, out_h5, actuals_h5=actuals_h5,
                       actuals_dset=actuals_dset, fcst_perc=fcst_perc)
 
 
