@@ -21,6 +21,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='RPM', type=STR,
               show_default=True,
               help='Job name. Default is "RPM".')
@@ -36,14 +37,6 @@ def main(ctx, name, verbose):
     ctx.obj['NAME'] = name
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 @main.command()
 def valid_config_keys():
     """
