@@ -7,8 +7,7 @@ import json
 import logging
 import numpy as np
 import os
-import pandas as pd
-from pandas.testing import assert_frame_equal
+from pyproj.crs import CRS
 import rasterio
 from warnings import warn
 
@@ -148,7 +147,35 @@ class ExclusionsConverter:
                 os.remove(excl_h5)
 
     @staticmethod
-    def _check_geotiff(excl_h5, geotiff, chunks=(128, 128),
+    def _check_crs(baseline_crs, test_crs, ignore_keys=('no_defs',)):
+        """
+        Compare baseline and test crs values
+
+        Parameters
+        ----------
+        baseline_crs : dict
+            Baseline CRS to use a truth, must be a dict
+        test_crs : dict
+            Test CRS to compare with baseline, must be a dictionary
+        ignore_keys : tuple
+            Keys to not check
+
+        Returns
+        -------
+        bad_crs : bool
+            Flag if crs' do not match
+        """
+        bad_crs = False
+        for k, true_v in baseline_crs.items():
+            if k not in ignore_keys:
+                test_v = test_crs.get(k, true_v)
+                if true_v != test_v:
+                    bad_crs = True
+
+        return bad_crs
+
+    @classmethod
+    def _check_geotiff(cls, excl_h5, geotiff, chunks=(128, 128),
                        transform_atol=0.01, coord_atol=0.001):
         """
         Compare geotiff with exclusion layer, raise any errors
@@ -182,25 +209,23 @@ class ExclusionsConverter:
                     raise ExclusionsCheckError(error)
 
                 profile = h5.profile
-                h5_crs = dict(i.split("=")
-                              for i in profile['crs'].split(' '))
-                h5_crs = pd.DataFrame(h5_crs, index=[0, ])
-                h5_crs = h5_crs.apply(pd.to_numeric, errors='ignore')
-
-                tif_crs = dict(i.split("=")
-                               for i in tif.profile['crs'].split(' '))
-                tif_crs = pd.DataFrame(tif_crs, index=[0, ])
-                tif_crs = tif_crs.apply(pd.to_numeric, errors='ignore')
-
-                cols = list(set(h5_crs.columns) & set(tif_crs.columns))
-                assert_frame_equal(h5_crs[cols], tif_crs[cols],
-                                   check_dtype=False, check_exact=False)
+                h5_crs = CRS.from_string(profile['crs']).to_dict()
+                tif_crs = CRS.from_string(tif.profile['crs']).to_dict()
+                bad_crs = cls._check_crs(h5_crs, tif_crs)
+                if bad_crs:
+                    error = ('Geospatial "crs" in {} and {} do not match!'
+                             '\n {} !=\n {}'
+                             .format(geotiff, excl_h5, tif_crs, h5_crs))
+                    logger.error(error)
+                    raise ExclusionsCheckError(error)
 
                 if not np.allclose(profile['transform'],
                                    tif.profile['transform'],
                                    atol=transform_atol):
                     error = ('Geospatial "transform" in {} and {} do not '
-                             'match!'.format(geotiff, excl_h5))
+                             'match!\n {} !=\n {}'
+                             .format(geotiff, excl_h5, profile['transform'],
+                                     tif.profile['transform']))
                     logger.error(error)
                     raise ExclusionsCheckError(error)
 
@@ -272,7 +297,7 @@ class ExclusionsConverter:
         excl_h5 : str
             Path to .h5 file containing exclusion layers
         layer : str
-            Exclusion layer to extract
+            Dataset name in .h5 file
         profile : dict
             Geotiff profile (attributes)
         values : ndarray
@@ -387,7 +412,14 @@ class ExclusionsConverter:
         if values.shape[0] != 1:
             values = np.expand_dims(values, 0)
 
-        profile['dtype'] = values.dtype.name
+        dtype = values.dtype.name
+        profile['dtype'] = dtype
+        if np.issubdtype(dtype, np.integer):
+            dtype_max = np.iinfo(dtype).max
+        else:
+            dtype_max = np.finfo(dtype).max
+
+        profile['nodata'] = dtype_max
 
         with rasterio.open(geotiff, 'w', **profile) as f:
             f.write(values)
